@@ -6,7 +6,7 @@ import apport.packaging
 
 from io import BytesIO
 
-from mock import patch
+from unittest.mock import patch
 
 
 class T(unittest.TestCase):
